Skip to content
Snippets Groups Projects
Commit 1d1a1c19 authored by Rafał Miłecki's avatar Rafał Miłecki
Browse files

bcm53xx: fix booting BCM4709


Signed-off-by: default avatarRafał Miłecki <zajec5@gmail.com>

SVN-Revision: 44218
parent ee758595
No related branches found
No related tags found
No related merge requests found
...@@ -59,6 +59,29 @@ index 0000000..2d7e388 ...@@ -59,6 +59,29 @@ index 0000000..2d7e388
+ 0x88000000 0x08000000>; + 0x88000000 0x08000000>;
+ }; + };
+}; +};
--- a/arch/arm/mach-bcm/bcm_5301x.c
+++ b/arch/arm/mach-bcm/bcm_5301x.c
@@ -35,15 +35,16 @@ static struct bcma_bus *bcm5301x_get_bcm
static int bcm5301x_abort_handler(unsigned long addr, unsigned int fsr,
struct pt_regs *regs)
{
- if (fsr == 0x1c06 && first_fault) {
+ if ((fsr == 0x1406 || fsr == 0x1c06) && first_fault) {
first_fault = false;
/*
* These faults with code 0x1c06 happens for no good reason,
* possibly left over from the CFE boot loader.
*/
pr_warn("External imprecise Data abort at addr=%#lx, fsr=%#x ignored.\n",
- addr, fsr);
+ addr, fsr);
/* Returning non-zero causes fault display and panic */
return 0;
-- --
1.8.4.5 1.8.4.5
...@@ -59,6 +59,29 @@ index 0000000..2d7e388 ...@@ -59,6 +59,29 @@ index 0000000..2d7e388
+ 0x88000000 0x08000000>; + 0x88000000 0x08000000>;
+ }; + };
+}; +};
@@ -35,15 +35,16 @@ static struct bcma_bus *bcm5301x_get_bcm
first_fault = false;
/*
- * These faults with code 0x1c06 happens for no good reason,
- * possibly left over from the CFE boot loader.
+ * These faults with codes 0x1406 (BCM4709) or 0x1c06 happens
+ * for no good reason, possibly left over from the CFE boot
+ * loader.
*/
pr_warn("External imprecise Data abort at addr=%#lx, fsr=%#x ignored.\n",
--- a/arch/arm/mach-bcm/bcm_5301x.c
+++ b/arch/arm/mach-bcm/bcm_5301x.c
@@ -35,15 +35,16 @@ static struct bcma_bus *bcm5301x_get_bcm
static int bcm5301x_abort_handler(unsigned long addr, unsigned int fsr,
struct pt_regs *regs)
{
- if (fsr == 0x1c06 && first_fault) {
+ if ((fsr == 0x1406 || fsr == 0x1c06) && first_fault) {
first_fault = false;
/*
* These faults with code 0x1c06 happens for no good reason,
* possibly left over from the CFE boot loader.
*/
pr_warn("External imprecise Data abort at addr=%#lx, fsr=%#x ignored.\n",
- addr, fsr);
+ addr, fsr);
/* Returning non-zero causes fault display and panic */
return 0;
-- --
1.8.4.5 1.8.4.5
0% Loading or .
You are about to add 0 people to the discussion. Proceed with caution.
@@ -35,15 +35,16 @@ static struct bcma_bus *bcm5301x_get_bcm
first_fault = false;
/*
- * These faults with code 0x1c06 happens for no good reason,
- * possibly left over from the CFE boot loader.
+ * These faults with codes 0x1406 (BCM4709) or 0x1c06 happens
+ * for no good reason, possibly left over from the CFE boot
+ * loader.
*/
pr_warn("External imprecise Data abort at addr=%#lx, fsr=%#x ignored.\n",
Finish editing this message first!
Please register or to comment